@@ -135,15 +135,20 @@ class VTBBigFather(RequestsGarant):
     }
 
     def __init__(self):
+        import urllib3
+        urllib3.disable_warnings()
         super().__init__()
-        self.url = 'https://epa.api.vtb.ru/openapi/smb/lecs/lead-impers/v1/'
+        # self.cert = f'{os.path.abspath(os.curdir)}/src/certs.pem'
+        self.verify = False
+        self.url = 'https://gw.api.vtb.ru:443/openapi/smb/lecs/lead-impers/v1/'
 
 
 class VTBToken(VTBBigFather):
     def __init__(self):
         super().__init__()
         self.data = self.credits
-        self.url = 'https://passport.api.vtb.ru/passport/oauth2/token'
+
+        self.url = 'https://open.api.vtb.ru:443/passport/oauth2/token'
         self.method = 'post'
 
     def do_json(self):
@@ -159,7 +164,8 @@ class VTBFather(VTBBigFather):
         self.json = json
 
     def exist_error_authorization(self):
-        for key, values in (('status', 'needConfirm'), ('httpMessage', 'Unauthorized')):
+        for key, values in (
+        ('reason', 'Unauthorized'), ('errorMessage', 'the header <Authorization> was not received in the request')):
             if key in self.response_json:
                 if self.response_json[key] == values:
                     return True
@@ -168,7 +174,10 @@ class VTBFather(VTBBigFather):
         vtbtoken = VTBToken()
         rezult = vtbtoken.get_rezult()
         if vtbtoken.success is True:
-            headers = {'Authorization': f'Bearer {rezult}'}
+            headers = {
+                'X-IBM-Client-Id': self.credits['client_id'].replace('@ext.vtb.ru', ''),
+                'Authorization': f'Bearer {rezult}'
+            }
             JS = JsonCustom(self.path_vtb_token)
             JS.data = headers
             JS.write()
@@ -248,6 +257,8 @@ class Open(RequestsGarantTestEndpoint):
         super().__init__()
         self.test = test
         self.headers = {
+            # 'Host': 'openpartners.ru',
+            # 'Content-Type': 'multipart/form-data',
             'X-Auth-Token': self.token
         }
 
@@ -444,6 +455,9 @@ class TochkaLead(Tochka):
     def do_json(self):
         if isinstance(self.response_json, list):
             if self.response_json:
+                if 'Не удалось определить пол' in self.response_json[0]:
+                    self.json['request'].update({'sex': 'M'})
+                    return self.get_rezult()
                 self.success = True
                 return self.response_json[0]
 
@@ -483,6 +497,36 @@ class TochkaAddDocs(Tochka):
                 return self.response_json
 
 
+class TochkaLeedRef(RequestsGarant):
+    def __init__(self, json):
+        super().__init__()
+        self.data = json
+
+        self.headers = {
+            'Accept': 'application/json, text/javascript, */*; q=0.01',
+            'Accept-Encoding': 'gzip, deflate, br',
+            'Accept-Language': 'ru-RU,ru;q=0.9,en-US;q=0.8,en;q=0.7',
+            'Cache-Control': 'no-cache',
+            'Connection': 'keep-alive',
+            'Content-Length': '2553',
+            'Content-Type': 'application/x-www-form-urlencoded; charset=UTF-8',
+            'Host': 'forms.tildacdn.com',
+            'Origin': 'https://partner.tochka.com',
+            'Pragma': 'no-cache',
+            'Referer': 'https://partner.tochka.com/',
+            'sec-ch-ua': '"Google Chrome";v="107", "Chromium";v="107", "Not=A?Brand";v="24"',
+            'sec-ch-ua-mobile': '?0',
+            'sec-ch-ua-platform': '"Windows"',
+            'Sec-Fetch-Dest': 'empty',
+            'Sec-Fetch-Mode': 'cors',
+            'Sec-Fetch-Site': 'cross-site',
+            'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/107.0.0.0 Safari/537.36'
+
+        }
+        self.method = 'post'
+        self.url = 'https://forms.tildacdn.com/procces/'
+
+
 class MoeDelo(RequestsGarantTestHeaders):
     headers = {'Content-Type': 'application/json; charset=UTF-8'}
     username = os.environ.get('moedelo_username')
@@ -564,16 +608,44 @@ class Raifazen(RequestsGarantTestBaseUrl):
         self.json = json
 
 
-class PSBall:
-    def __init__(self):
+class PSBall(RequestsGarantTestBaseUrl):
+    base_url = 'https://api.lk.psbank.ru/fo/v1.0.0'
+    # base_url = 'https://api.lk.psb.services/fo/v1.0.0'
+    base_url_test = 'https://api.lk.finstar.online/fo/v1.0.0'
+
+    def __init__(self, test):
+        super().__init__()
+        # self.session = session
         self.test = test
-        if test is True:
-            self.url = 'https://api.lk.finstar.online/fo/v1.0.0'
-        else:
-            self.url = 'https://api.lk.psbank.ru/fo/v1.0.0'
+
+    def do_json(self):
+        if 'status' in self.response_json:
+            if self.response_json['status'] == 429:
+                time.sleep(3)
+                return self.get_rezult()
+        return self.do_json_wrapper()
+
+    # def get_response_production(self):
+    #     return self.session.request(**self.args_request)
 
 
-class PSBToken(PSBall, RequestsGarant):
+# class PSBall:
+#     def __init__(self):
+#         self.test = test
+#         if test is True:
+#             self.url = 'https://api.lk.finstar.online/fo/v1.0.0'
+#         else:
+#             self.url = 'https://api.lk.psbank.ru/fo/v1.0.0'
+
+
+class PSBToken(PSBall):
+    def __init__(self, test):
+        super().__init__(test)
+        self.method = 'post'
+        # self.data = {"email": "andrevo@bk.ru", "password": "0831254Aa."}
+        self.data = {"email": os.environ.get('psb_email'), "password": os.environ.get('psb_password')}
+        self.endpoint = '/user/login'
+
     def do_json(self):
         if 'data' in self.response_json:
             data = self.response_json['data']
@@ -581,8 +653,8 @@ class PSBToken(PSBall, RequestsGarant):
                 self.success = True
                 return data['access_token']
 
-    def get_response(self):
-        return self.session.post(f'{self.url}/user/login', data={"email": "andrevo@bk.ru", "password": "0831254Aa."})
+    # def get_response(self):
+    #     return self.session.post(f'{self.url}/user/login', data={"email": "andrevo@bk.ru", "password": "0831254Aa."})
 
 
 class PSBParent(RequestsGarantTestBaseUrl):
@@ -594,78 +666,47 @@ class PSBParent(RequestsGarantTestBaseUrl):
         self.test = test
 
 
-class PSB(PSBParent):
-    email = os.environ.get('psb_email')
-    password = os.environ.get('psb_password')
+class PSBScoring(PSBall):
 
-    def __init__(self, session, test=test):
+
+    def __init__(self, json_dict, token, test=test):
         super().__init__(test)
-        self.session = session
-        self.access_token = self.create_token()
-
-    def create_token(self):
-        for i in range(0, 3):
-            self.access_token = self.get_rezult()
-            if self.success is True:
-                return self.access_token
-
-    def get_response(self):
-        return self.session.post(f'{self.url}/user/login', data={"email": self.email, "password": self.password})
-
-    def receive_condition(self):
-        if 'data' in self.response_json:
-            data = self.response_json['data']
-            if 'access_token' in data:
-                self.success = True
-                return data['access_token']
-            else:
-                return data
-
-
-class PSBCity(PSB, CityBankes):
-    def __init__(self, session):
-        PSB.__init__(self, session)
-        CityBankes.__init__(self)
-
-
-class PSBScoring(PSB):
-    endpoint = '/orders/check-inn?access-token='
-
-    def __init__(self, json_dict, session, test=test):
-        super().__init__(session, test)
         self.json = json_dict
+        self.endpoint = f'/orders/check-inn?access-token={token}'
+        self.method = 'post'
 
-    def get_response_production(self):
-        return self.session.post(
-            url=f'{self.url}{self.access_token}',
-            json=self.json,
-            timeout=5
-        )
 
-    def do_json(self):
-        if 'data' in self.response_json:
-            data = self.response_json['data']
-            if 'access_token' in data:
+    def do_json_wrapper(self):
+        if 'status' in self.response_json:
+            if self.response_json['status'] == 'NOT_EXISTS':
                 self.success = True
-                return data['access_token']
-            else:
-                return data
+                return inn_freedom
+            elif self.response_json['status'] == 'ALREADY_EXISTS':
+                self.success = True
+                return inn_busy
 
 
-class PSBLead(PSB):
-    endpoint = '/orders?access-token='
 
-    def __init__(self, json, session, test=test):
-        super().__init__(session, test)
-        self.json = json
 
-    def get_response_production(self):
-        return self.session.post(f"{self.url}{self.access_token}", json=self.json)
+
+class PSBLead(PSBall):
+
+
+    def __init__(self, json_dict, token, test=test):
+        super().__init__(test)
+        self.json = json_dict
+        self.endpoint = f'/orders?access-token={token}'
+        self.method = 'post'
 
     def do_json(self):
         if 'data' in self.response_json:
             if 'id' in self.response_json['data']:
                 self.success = True
                 return self.response_json['data']['id']
-            else:
-                return self.response_json
+
+        elif 'errors' in self.response_json:
+            if 'message' in self.response_json['errors']:
+                if self.response_json['errors']['message'] == 'inn: В системе найден дубликат.':
+                    self.success = True
+                    return inn_busy
+
